@@ -445,7 +445,7 @@ def PointRotateAxis(u, rp, r, theta):
 
     """
     # construct augmented vector rr = [r;1]
-    rr = r
+    rr = r[:] # Making a copy
     rr.append(1)
     # rotation matrix about arbitrary line through rp
     R = [[0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0]]
@@ -1102,7 +1102,7 @@ def aligntoaxis2(mol, Rr, Rp, u, d):
 
 
 def alignPtoaxis(Rr, Rp, u, d):
-    """Translates point and aligns to axis
+    """Translates point and aligns to axis.
 
     Parameters
     ----------
@@ -1186,11 +1186,12 @@ def connectivity_match(inds1, inds2, mol1, mol2):
 
     """
     match = False
-    if len(inds1) == len(inds2):
-        inds1.sort()
-        inds2.sort()
-        _mol1 = mol1.create_mol_with_inds(inds1)
-        _mol2 = mol2.create_mol_with_inds(inds2)
+    inds1c, inds2c = inds1[:], inds2[:] # Making copies
+    if len(inds1c) == len(inds2c):
+        inds1c.sort()
+        inds2c.sort()
+        _mol1 = mol1.create_mol_with_inds(inds1c)
+        _mol2 = mol2.create_mol_with_inds(inds2c)
         _mol1.createMolecularGraph()
         _mol2.createMolecularGraph()
         match = np.array_equal(_mol1.graph, _mol2.graph)
@@ -1222,3 +1223,31 @@ def best_fit_plane(coordinates):
     # the corresponding left singular vector is the normal vector of the best-fitting plane
     normal_vector_plane = left[:, -1]
     return normal_vector_plane
+
+def move_point(initial_point, vector, distance):
+    """
+    Move a point along a vector by a given distance.
+
+    Parameters:
+    initial_point (array-like): The starting point [x, y, z].
+    vector (array-like): The direction vector [dx, dy, dz].
+    distance (float): The distance to move along the vector.
+
+    Returns:
+    numpy.ndarray: The new point after moving.
+    """
+    # Convert inputs to numpy arrays
+    initial_point = np.array(initial_point)
+    vector = np.array(vector)
+
+    # Normalize the vector
+    norm = np.linalg.norm(vector)
+    if norm == 0:
+        raise ValueError("The vector cannot be zero.")
+    unit_vector = vector / norm
+
+    # Calculate the new point
+    displacement = unit_vector * distance
+    new_point = initial_point + displacement
+
+    return new_point
