@@ -1,7 +1,8 @@
 import numpy as np
 from scipy.optimize import linear_sum_assignment
 from scipy.spatial.distance import cdist
-
+from molSimplify.Scripts.align import project_onto_principal_axes, rotate_onto_principal_axes
+from itertools import combinations
 
 def rmsd(V, W):
     """Calculate Root-mean-square deviation from two sets of vectors V and W.
@@ -292,7 +293,7 @@ def reorder_hungarian(p_atoms, q_atoms, p_coord, q_coord):
     ----------
         p_atoms : np.array
             (N,1) matrix, where N is points holding the atoms' names
-        p_atoms : np.array
+        q_atoms : np.array
             (N,1) matrix, where N is points holding the atoms' names
         p_coord : np.array
             (N,D) matrix, where N is points and D is dimension
@@ -447,16 +448,97 @@ def rmsd_reorder_rotate(p_atoms, q_atoms, p_coord, q_coord,
         result_rmsd = rotation_method(p_coord, q_coord)
     return result_rmsd
 
+def reorder_rotate(p_atoms, q_atoms, p_coord, q_coord,
+                   rotation="kabsch", reorder="hungarian",
+                   translate=True, return_reorder=False):
+    """Reorders atoms pairwise and rotates structures onto one another.
 
-def rigorous_rmsd(mol1, mol2, rotation: str = "kabsch",
+    Parameters
+    ----------
+        p_atoms : np.array
+            Atom symbol list.
+        q_atoms : np.array
+            Atom symbol list.
+        p_coord : np.array
+            List of coordinates for p_atoms.
+        q_atoms : np.array
+            List of coordinates for q_atoms.
+        rotation : str, optional
+            Rotation method. Default is kabsch.
+        reorder : str, optional
+            Reorder method. Default is hungarian.
+        translate : bool, optional
+            Whether or not the molecules should be translated
+            such that their centroid is at the origin.
+            Default is True.
+        return_reorder : bool, optional
+            Whether or not the reordering is returned.
+            Default is False.
+
+    Returns
+    -------
+        q_coords : np.array
+            New coordinates for molecule q after reordering and reassignment.
+
+    """
+    if not p_atoms.shape[0] == q_atoms.shape[0]:
+        print(("Warning: Number of atoms do not match!",
+               p_atoms.shape[0], q_atoms[0]))
+        return 1000
+    elif not len(set(np.unique(p_atoms)) - set(np.unique(q_atoms))) == 0:
+        print(("Warning: Atom types do not match!",
+               np.unique(p_atoms), np.unique(q_atoms)))
+        return 1000
+    if translate:
+        p_cent = centroid(p_coord)
+        q_cent = centroid(q_coord)
+        p_coord -= p_cent
+        q_coord -= q_cent
+
+    # set rotation method
+    if rotation.lower() == "kabsch":
+        rotation_method = kabsch_rotate
+    elif rotation.lower() == "quaternion":
+        rotation_method = quaternion_rotate
+    elif rotation.lower() == "none":
+        rotation_method = None
+    else:
+        raise ValueError("error: Unknown rotation method:", rotation)
+
+    # set reorder method
+    if reorder.lower() == "hungarian":
+        reorder_method = reorder_hungarian
+    elif reorder.lower() == "distance":
+        reorder_method = reorder_distance
+    elif reorder.lower() == "none":
+        reorder_method = None
+    else:
+        raise ValueError("error: Unknown reorder method:", reorder)
+
+    if not reorder.lower() == "none":
+        q_review = reorder_method(p_atoms, q_atoms, p_coord, q_coord)
+        q_coord = q_coord[q_review]
+        # q_atoms = q_atoms[q_review]
+        #print("q_review", q_review)
+
+    if rotation_method is not None:
+        q_coord = rotation_method(q_coord, p_coord)
+
+    if return_reorder:
+        return q_coord, q_review
+    else:
+        return q_coord
+
+
+def rigorous_rmsd(mol_p, mol_q, rotation: str = "kabsch",
                   reorder: str = "hungarian") -> float:
     """Rigorous RMSD measurement
 
     Parameters
     ----------
-        mol1 : mol3D
+        mol_p : mol3D
             mol3D instance of initial molecule.
-        mol2 : np.mol3D
+        mol_q : mol3D
             mol3D instance of final molecule.
         rotation : str, optional
             Rotation method. Default is kabsch.
@@ -469,89 +551,208 @@ def rigorous_rmsd(mol1, mol2, rotation: str = "kabsch",
             Resulting RMSD from aligning and rotating.
 
     """
-    mol1_atoms = mol1.symvect()
-    mol1_coords = mol1.coordsvect()
-    mol2_atoms = mol2.symvect()
-    mol2_coords = mol2.coordsvect()
-    result_rmsd = rmsd_reorder_rotate(mol1_atoms, mol2_atoms, mol1_coords, mol2_coords,
+    molp_atoms = mol_p.symvect()
+    molp_coords = mol_p.coordsvect()
+    molq_atoms = mol_q.symvect()
+    molq_coords = mol_q.coordsvect()
+    result_rmsd = rmsd_reorder_rotate(molp_atoms, molq_atoms, molp_coords, molq_coords,
                                       rotation=rotation, reorder=reorder)
     return result_rmsd
 
-def align_rmsd(mol1, mol2, rotation: str = "kabsch",
-               reorder: str = "hungarian") -> float:
+def align_rmsd_project(mol_p, mol_q, rotation: str = "kabsch",
+               reorder: str = "hungarian", verbose=False, iterations=1) -> float:
     """
-    Computes the RMSD between 2 mol objects after:
-    - translating them both such that the center of mass is at the origin
-    - projecting the coordinates onto the principal axes
-    - reordering x, y, z such that Ixx < Iyy < Izz
-    (will allow for 180degree rotations about x, y, z, as well as
-    reflections about the xy, xz, yz, and all three of those planes)
+    Computes the RMSD between 2 mol3D objects after: (1) translating them both such that
+    the center of mass is at the origin, (2) projecting the coordinates onto the principal
+    axes  (Note that the projection may lead to reflections, which will break chirality), and
+    (3) reordering x, y, z such that Ixx < Iyy < Izz. The function will also allow for 180
+    degree rotations about x, y, z, as well as reflections about the xy, xz, yz planes, and
+    combinations of rotations and reflections.
 
     Parameters
     ----------
-        mol1 : mol3D
+        mol_p : mol3D
             mol3D instance of initial molecule.
-        mol2 : np.mol3D
+        mol_q : np.mol3D
             mol3D instance of final molecule.
         rotation : str, optional
             Rotation method. Default is kabsch.
         reorder : str, optional
             Reorder method. Default is hungarian.
+        verbose : bool, optional
+            Will show a warning if the principal moments of inertia are close in magnitude,
+            which could indicate an undesired ordering of the axes.
+        iterations : int, optional
+            Gives the number of iterations (reassigning atoms, rotating) allowed before
+            the algorithm stops. Default is 1 (one initial reassignment followed by one rotation).
+            Increased iterations may help get more reasonable RMSDs in some cases.
 
     Returns
     -------
         rmsd : float
             Resulting RMSD from aligning and rotating.
     """
+    molp_atoms = mol_p.symvect()
+    molp_coords = project_onto_principal_axes(mol_p)
 
-    mol1_atoms = mol1.symvect()
-    cm1 = mol1.centermass()
-    pmom1, P1 = mol1.principal_moments_of_inertia(return_transform=True)
-    for atom in mol1.atoms:
-        atom.setcoords(np.array(atom.coords()) - cm1) #center
-        atom.setcoords(P1.dot(atom.coords())) #project onto principal moments
-        #sort the coordinates so that the largest princiipal moment is first
-        atom.setcoords(np.array(atom.coords())[np.argsort(pmom1)].flatten())
-    mol1_coords = mol1.coordsvect()
-
-    #note: the above aligns the largest moment of inertia with z, the smallest with x
-    #does not account for whether it is aligned with + or - part of an axis
-    #so, have to allow for 180deg rotations and reflections as well
-
-    rmsd = np.inf
+    best_rmsd = np.inf
     x_rot = np.array([[1, 0, 0], [0, -1, 0], [0, 0, -1]]) #180 about x
     y_rot = np.array([[-1, 0, 0], [0, 1, 0], [0, 0, -1]]) #180 about y
     z_rot = np.array([[-1, 0, 0], [0, -1, 0], [0, 0, 1]]) #180 about z
     x_ref = np.array([[-1, 0, 0], [0, 1, 0], [0, 0, 1]]) #reflect about yz
     y_ref = np.array([[1, 0, 0], [0, -1, 0], [0, 0, 1]]) #reflect about xz
     z_ref = np.array([[1, 0, 0], [0, 1, 0], [0, 0, -1]]) #reflect about xy
-    a_ref = np.array([[-1, 0, 0], [0, -1, 0], [0, 0, -1]]) #reflect all 3
     transformations = [
         np.eye(3), #no change
         x_rot, y_rot, z_rot,
-        x_ref, y_ref, z_ref, a_ref
+        x_rot@y_rot, x_rot@z_rot, y_rot@z_rot,
+        x_rot@y_rot@z_rot,
+        x_ref, y_ref, z_ref,
+        x_ref@y_ref, x_ref@z_ref, y_ref@z_ref,
+        x_ref@y_ref@z_ref
     ]
-    mol2_atoms = mol2.symvect()
-    cm2 = mol2.centermass()
-    pmom2, P2 = mol2.principal_moments_of_inertia(return_transform=True)
-    for atom in mol2.atoms:
-        atom.setcoords(np.array(atom.coords()) - cm2) #center
-        atom.setcoords(P2.dot(atom.coords())) #project onto principal moments
-        #sort the coordinates so that the largest princiipal moment is first
-        atom.setcoords(np.array(atom.coords())[np.argsort(pmom2)].flatten())
-    for transformation in transformations:
-        for atom in mol2.atoms:
-            atom.setcoords(transformation @ np.array(atom.coords()))
-        mol2_coords = mol2.coordsvect()
-        #revert transformations
-        for atom in mol2.atoms:
-            atom.setcoords(np.linalg.inv(transformation) @ np.array(atom.coords()))
 
-        result_rmsd = rmsd_reorder_rotate(mol1_atoms, mol2_atoms, mol1_coords, mol2_coords,
-                                          rotation=rotation, reorder=reorder, translate=True)
-        if result_rmsd < rmsd:
-            rmsd = result_rmsd
-    return rmsd
+    molq_atoms = mol_q.symvect()
+    molq_coords = project_onto_principal_axes(mol_q)
+
+    for transformation in transformations:
+        transformed_molq_coords = np.vstack([transformation @ molq_coords[i, :] for i in range(len(molq_coords))])
+
+        #Iterate for the specified number of iterations
+        for i in range(iterations):
+            transformed_molq_coords = reorder_rotate(molp_atoms, molq_atoms, molp_coords, transformed_molq_coords,
+                                                     rotation=rotation, reorder=reorder, translate=True)
+
+            if i == iterations-1:
+                #for the final iteration, compute the RMSD and compare
+                result_rmsd = rmsd(molp_coords, transformed_molq_coords)
+
+                if result_rmsd < best_rmsd:
+                    best_rmsd = result_rmsd
+
+    if verbose:
+        cutoff = 10 #How close moments have to be for a warning
+        pmom1 = mol_p.principal_moments_of_inertia()
+        if np.abs(pmom1[0] - pmom1[1]) < cutoff or np.abs(pmom1[0] - pmom1[2]) < cutoff or np.abs(pmom1[1] - pmom1[2]) < cutoff:
+            print('The principal moments of the first mol3D are close in magnitude, and are:')
+            print(pmom1)
+            print('This may lead to improper orientation in some cases.')
+        pmom2 = mol_q.principal_moments_of_inertia()
+        if np.abs(pmom2[0] - pmom2[1]) < cutoff or np.abs(pmom2[0] - pmom2[2]) < cutoff or np.abs(pmom2[1] - pmom2[2]) < cutoff:
+            print('The principal moments of the second mol3D are close in magnitude, and are:')
+            print(pmom2)
+            print('This may lead to improper orientation in some cases.')
+
+        #Can address improper rotations by also allowing 90 degree rotations, combinations (including 180 rotations as well)
+
+    return best_rmsd
+
+def align_rmsd_rotate(mol_p, mol_q, rotation: str = "kabsch",
+               reorder: str = "hungarian", verbose=False, iterations=1) -> float:
+    """
+    Computes the RMSD between 2 mol objects after: (1) translating them both
+    such that the center of mass is at the origin, (2) rotating them onto their
+    principal axes such that Izz > Iyy > Ixx. Allows 180 degree rotations
+    about the coordinate axes and combinations of those rotations.
+
+    Parameters
+    ----------
+        mol_p : mol3D
+            mol3D instance of initial molecule.
+        mol_q : np.mol3D
+            mol3D instance of final molecule.
+        rotation : str, optional
+            Rotation method. Default is kabsch.
+        reorder : str, optional
+            Reorder method. Default is hungarian.
+        verbose : bool, optional
+            Will show a warning if the principal moments of inertia are close in magnitude,
+            which could indicate an undesired ordering of the axes.
+        iterations : int, optional
+            Gives the number of iterations (reassigning atoms, rotating) allowed before
+            the algorithm stops. Default is 1 (one initial reassignment followed by one rotation).
+            Increased iterations may help get more reasonable RMSDs in some cases.
+
+    Returns
+    -------
+        best_rmsd : float
+            Resulting RMSD from aligning and rotating.
+    """
+    #for the first mol object, get the symbols and atoms
+    molp_atoms = mol_p.symvect()
+    molp_coords = rotate_onto_principal_axes(mol_p)
+
+    molq_atoms = mol_q.symvect()
+    molq_coords = rotate_onto_principal_axes(mol_q)
+
+    if verbose:
+        print('Molecule 1 on principal axes:')
+        print(mol_p.natoms, '\n')
+        for i, atom in enumerate(mol_p.getAtoms()):
+            xyz = molp_coords[i]
+            ss = "%s \t%f\t%f\t%f" % (atom.sym, xyz[0], xyz[1], xyz[2])
+            print(ss)
+
+        print('Molecule 2 on principal axes:')
+        print(mol_q.natoms, '\n')
+        for i, atom in enumerate(mol_q.getAtoms()):
+            xyz = molq_coords[i]
+            ss = "%s \t%f\t%f\t%f" % (atom.sym, xyz[0], xyz[1], xyz[2])
+            print(ss)
+
+    #allow 180 degree rotations about each axis to catch if aligned to different sides
+    best_rmsd = np.inf
+    x_rot = np.array([[1, 0, 0], [0, -1, 0], [0, 0, -1]]) #180 about x
+    y_rot = np.array([[-1, 0, 0], [0, 1, 0], [0, 0, -1]]) #180 about y
+    z_rot = np.array([[-1, 0, 0], [0, -1, 0], [0, 0, 1]]) #180 about z
+    transformations = [
+        np.eye(3), #no change
+        x_rot, y_rot, z_rot]
+
+    for transformation in transformations:
+        transformed_molq_coords = np.vstack([transformation @ molq_coords[i, :] for i in range(len(molq_coords))])
+
+        #Iterate for the specified number of iterations
+        for i in range(iterations):
+            if verbose:
+                transformed_molq_coords, q_review = reorder_rotate(molp_atoms, molq_atoms, molp_coords, transformed_molq_coords,
+                                                     rotation=rotation, reorder=reorder, translate=True, return_reorder=True)
+            else:
+                transformed_molq_coords = reorder_rotate(molp_atoms, molq_atoms, molp_coords, transformed_molq_coords,
+                                                     rotation=rotation, reorder=reorder, translate=True, return_reorder=False)
+
+
+            if i == iterations-1:
+                #for the final iteration, compute the RMSD and compare
+                result_rmsd = rmsd(molp_coords, transformed_molq_coords)
+
+                if result_rmsd < best_rmsd:
+                    best_rmsd = result_rmsd
+                    if verbose:
+                        print('Aligned molecule 2:')
+                        print(f'The transformation is {transformation}.')
+                        print(f'The RMSD is {result_rmsd}.')
+                        print(mol_q.natoms, '\n')
+                        symbs = molq_atoms[q_review]
+                        for j, atom in enumerate(mol_q.getAtoms()):
+                            xyz = transformed_molq_coords[j]
+                            ss = "%s \t%f\t%f\t%f" % (symbs[j], xyz[0], xyz[1], xyz[2])
+                            print(ss)
+
+    if verbose:
+        cutoff = 10 #How close moments have to be for a warning
+        pmom1 = mol_p.principal_moments_of_inertia()
+        if np.abs(pmom1[0] - pmom1[1]) < cutoff or np.abs(pmom1[0] - pmom1[2]) < cutoff or np.abs(pmom1[1] - pmom1[2]) < cutoff:
+            print('The principal moments of the first mol3D are close in magnitude, and are:')
+            print(pmom1)
+            print('This may lead to improper orientation in some cases.')
+        pmom2 = mol_q.principal_moments_of_inertia()
+        if np.abs(pmom2[0] - pmom2[1]) < cutoff or np.abs(pmom2[0] - pmom2[2]) < cutoff or np.abs(pmom2[1] - pmom2[2]) < cutoff:
+            print('The principal moments of the second mol3D are close in magnitude, and are:')
+            print(pmom2)
+            print('This may lead to improper orientation in some cases.')
+
+    return best_rmsd
 
 def test_case():
     p_atoms = np.array(["N", "H", "H", "H"])
