@@ -93,7 +93,7 @@ def invoke_ANNs_from_mol3d(mol: mol3D, oxidation_state: int,
 
 
 def tf_check_ligands(ligs: List[str], batslist: List[List[int]],
-                     dents: List[int], tcats: List[str],
+                     dents: List[int], tcats: List[List[Union[int, str]]],
                      occs: List[int], debug: bool):
     # tests if ligand combination
     # is compatible with the ANN
@@ -121,8 +121,8 @@ def tf_check_ligands(ligs: List[str], batslist: List[List[int]],
     equatorial_ligs = []
     ax_dent = 0
     eq_dent = 0
-    eq_tcat = ''
-    ax_tcat = ''
+    eq_tcat = []
+    ax_tcat = []
     pentadentate = False
     ax_occs = []
     eq_occs = []
@@ -241,13 +241,15 @@ def tf_check_ligands(ligs: List[str], batslist: List[List[int]],
                 eq_occs.append(occs[i])
                 equatorial_ind_list.append(i)
     if (len(axial_ligs) > 2):
-        print(('axial lig error : ', axial_ligs, ax_dent, ax_tcat, ax_occs))
+        print('ANN setup error: axial lig error : ',
+              axial_ligs, ax_dent, ax_tcat, ax_occs)
         valid = False
     if debug:
         print(('eq occupations  ' + str(eq_occs)))
         print(('eq dent   ' + str(eq_dent)))
     if not (4.0 / (float(eq_dent) * sum(eq_occs)) == 1):
-        print(('equatorial ligs error: ', equatorial_ligs, eq_dent, eq_tcat))
+        print('ANN setup error: equatorial ligs error: ',
+              equatorial_ligs, eq_dent, eq_tcat)
         valid = False
     if valid and len(axial_ind_list) == 0:  # get the index position in ligs
         axial_ind_list = [ligs.index(ax_lig) for ax_lig in axial_ligs]
@@ -274,7 +276,7 @@ def check_metal(metal: str, oxidation_state: str) -> Tuple[bool, str]:
 
 
 def tf_ANN_preproc(metal: str, oxstate, spin, ligs: List[str], occs: List[int], dents: List[int],
-                   batslist: List[List[int]], tcats: List[str],
+                   batslist: List[List[int]], tcats: List[List[Union[int, str]]],
                    licores: dict, decoration, decoration_index, exchange, geometry: str = "oct",
                    debug: bool = False) -> Tuple[bool, str, dict, bool]:
     # prepares and runs ANN calculation
