@@ -10,7 +10,8 @@ def test_parseinputfile_empty():
     defaults = {'skipANN': False, 'oldANN': False,
                 'dbvdent': False, 'dbvconns': False,
                 'dbvhyb': False, 'dbvlinks': False,
-                'rprompt': False, 'rundir': f'{os.getcwd()}/Runs'}
+                'rprompt': False, 'rundir': f'{os.getcwd()}/Runs',
+                'overwrite': False,}
 
     args = Namespace()
     parseinputfile(args, inputfile_str=' ')
@@ -40,7 +41,7 @@ def test_parseinputs_advanced(monkeypatch):
     defaults = dict(MLbonds=False, antigeoisomer=None, calccharge=True,
                     charge=None, decoration=False, decoration_index=False,
                     distort='0', genall=False, isomers=None, langles=False,
-                    ligalign=False, nconfs='1', oldANN=None, pangles=False,
+                    ligalign=False, nconfs='1', no_tabs=False, oldANN=None, pangles=False,
                     reportonly=None, scoreconfs=False, stereos=None,
                     jobmanager=False)
     assert args.__dict__ == defaults
